"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MongoAppender = void 0;
const log4js = require("log4js");
const os = require("os");
const getMongoDb_1 = require("./sources/getMongoDb");
const logger = log4js.getLogger();
let dbConnection;
function configure(config, layouts) {
    config.minLevel = config.minLevel || log4js.levels.ERROR;
    config.maxLevel = config.maxLevel || log4js.levels.FATAL;
    config.env = config.env || {
        hostName: os.hostname(),
        platform: os.platform(),
    };
    InitDb(config);
    let layout = layouts.messagePassThroughLayout;
    if (config.layout) {
        layout = layouts.layout(config.layout.type, config.layout);
    }
    return LogMessage(config, layout);
}
exports.MongoAppender = {
    configure: configure,
};
function isClient(client) {
    return client.collection !== undefined;
}
function InitDb(config) {
    if (!dbConnection && config) {
        if (isClient(config.mongoSetting)) {
            (0, getMongoDb_1.default)(config.mongoSetting, (err, connection) => {
                if (err || !connection) {
                    logger.error(err);
                }
                else {
                    dbConnection = connection;
                }
            });
        }
        else {
            dbConnection = config.mongoSetting.client
                .db(config.database)
                .collection(config.collection);
        }
    }
}
function LogMessage(config, layout) {
    const logPrefix = `${__filename}[${LogMessage.name}]`;
    return (loggingEvent) => {
        const actLevel = log4js.levels.getLevel(loggingEvent.level.levelStr);
        if (config.minLevel &&
            config.maxLevel &&
            (actLevel.level < config.minLevel.level ||
                actLevel.level > config.maxLevel.level)) {
            return;
        }
        let jsonData = loggingEvent;
        if (layout) {
            const data = layout(loggingEvent);
            try {
                jsonData = JSON.parse(data);
            }
            catch (err) { }
        }
        dbConnection.insertOne(jsonData, (err) => {
            if (err) {
                logger.error(logPrefix + err);
            }
        });
    };
}
//# sourceMappingURL=index.js.map